package com.ruoyi.api.controller;

import com.alibaba.fastjson.JSONObject;
import com.ruoyi.api.domain.InStoreDto;
import com.ruoyi.api.domain.OutStoreDto;
import com.ruoyi.api.domain.StockDto;
import com.ruoyi.api.service.impl.ApiService;
import com.ruoyi.common.core.domain.AjaxResult;

import static com.ruoyi.common.core.domain.AjaxResult.*;

import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.manage.domain.BaseLocation;
import com.ruoyi.manage.domain.BaseManufacturer;
import com.ruoyi.manage.domain.RecordStoreCheck;
import com.ruoyi.manage.service.IBaseLocationService;
import com.ruoyi.manage.service.IBaseManufacturerService;
import com.ruoyi.manage.service.IRecordStoreCheckService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.unit.DataUnit;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;
import java.util.Map;


/**
 * @author wanghao
 * @date 2024/1/11  8:55
 */
@RestController
@RequestMapping("/api")
public class ApiController {
    @Autowired
    private IBaseLocationService baseLocationService;
    @Autowired
    private IBaseManufacturerService baseManufacturerService;
    @Autowired
    private ApiService apiService;

    //入库
    // 查询库位 和 品牌
    @PostMapping("/instore/select")
    public AjaxResult instoreSelect() {
        BaseLocation baseLocation = new BaseLocation();
        baseLocation.setStoteTag(1L);
        baseLocation.setIsEnable("Y");
        List<BaseLocation> baseLocationList = baseLocationService.selectBaseLocationList(baseLocation);
        BaseManufacturer baseManufacturer = new BaseManufacturer();
        baseManufacturer.setIsEnable("Y");
        List<BaseManufacturer> baseManufacturerList = baseManufacturerService.selectBaseManufacturerList(baseManufacturer);
        Map<String, List> map = new HashMap<>();
        map.put("baseLocationList", baseLocationList);
        map.put("baseManufacturerList", baseManufacturerList);
        return success(map);
    }

    @PostMapping("/instore/submit")
    public AjaxResult instoreSubmit(@RequestBody InStoreDto inStore) {
        apiService.submintInsertRecordIn(inStore);
        apiService.submintInsertLedger(inStore);
        return success();
    }


    @PostMapping("/outStore/select")
    public AjaxResult outStoreSelect() {
        BaseLocation baseLocation = new BaseLocation();
        baseLocation.setStoteTag(2L);
        baseLocation.setIsEnable("Y");
        List<BaseLocation> baseLocationList = baseLocationService.selectBaseLocationList(baseLocation);
        return success(baseLocationList);
    }

    @PostMapping("/outStore/submit")
    public AjaxResult outStoreSubmit(@RequestBody OutStoreDto outStoreDto) {
        apiService.submitInsertRecordOut(outStoreDto);
        apiService.updataLedger(outStoreDto);
        return success();
    }

    @PostMapping("/storecheck/select")
    public AjaxResult storeCheckSelect() {
        List<StockDto> list = apiService.storeCheckSelect();
        if (list == null || list.isEmpty()) {
            return error("库存为空");
        }
        return success(list);
    }

    @Autowired
    private IRecordStoreCheckService checkService;

    @Transactional
    @PostMapping("/storecheck/submit")
    public AjaxResult storeCheckSubmit(String json , String user) {
        try {
            List<StockDto> list= JSONObject.parseArray(json,StockDto.class);
            RecordStoreCheck recordStoreCheck = new RecordStoreCheck();
            recordStoreCheck.setCheckNumber(list.size());
            recordStoreCheck.setCheckTime(DateUtils.getNowDate());
            recordStoreCheck.setCheckUser(user);
            int key = checkService.insertRecordStoreCheck(recordStoreCheck);
            apiService.insertCheckInfo(list,recordStoreCheck.getCheckId());
            return success();
        }catch (Exception e){
            return error("数据异常,请求失败");
        }

    }
}
